@@ -767,7 +767,7 @@ var LibraryPThread = {
     return 0;
   },
 
-  // Stores the memory address that the main thread is futexWaiting on, if any.
+  // Stores the memory address that the main thread is waiting on, if any.
   _main_thread_futex_wait_address: '; if (ENVIRONMENT_IS_PTHREAD) __main_thread_futex_wait_address = PthreadWorkerInit.__main_thread_futex_wait_address; else PthreadWorkerInit.__main_thread_futex_wait_address = __main_thread_futex_wait_address = allocate(1, "i32*", ALLOC_STATIC)',
 
   // Returns 0 on success, or one of the values -ETIMEDOUT, -EWOULDBLOCK or -EINVAL on error.
@@ -779,17 +779,17 @@ var LibraryPThread = {
 #if PTHREADS_PROFILING
       PThread.setThreadStatusConditional(_pthread_self(), {{{ cDefine('EM_THREAD_STATUS_RUNNING') }}}, {{{ cDefine('EM_THREAD_STATUS_WAITFUTEX') }}});
 #endif
-      var ret = Atomics.futexWait(HEAP32, addr >> 2, val, timeout);
+      var ret = Atomics.wait(HEAP32, addr >> 2, val, timeout);
 //    dump('futex_wait done by thread: ' + _pthread_self() + (ENVIRONMENT_IS_PTHREAD?'(pthread)':'') + '\n');
 #if PTHREADS_PROFILING
       PThread.setThreadStatusConditional(_pthread_self(), {{{ cDefine('EM_THREAD_STATUS_WAITFUTEX') }}}, {{{ cDefine('EM_THREAD_STATUS_RUNNING') }}});
 #endif
-      if (ret == Atomics.TIMEDOUT) return -{{{ cDefine('ETIMEDOUT') }}};
-      if (ret == Atomics.NOTEQUAL) return -{{{ cDefine('EWOULDBLOCK') }}};
-      if (ret == 0) return 0;
-      throw 'Atomics.futexWait returned an unexpected value ' + ret;
+      if (ret === Atomics.TIMEDOUT) return -{{{ cDefine('ETIMEDOUT') }}};
+      if (ret === Atomics.NOTEQUAL) return -{{{ cDefine('EWOULDBLOCK') }}};
+      if (ret === Atomics.OK) return 0;
+      throw 'Atomics.wait returned an unexpected value ' + ret;
     } else {
-      // Atomics.futexWait is not available in the main browser thread, so simulate it via busy spinning.
+      // Atomics.wait is not available in the main browser thread, so simulate it via busy spinning.
       var loadedVal = Atomics.load(HEAP32, addr >> 2);
       if (val != loadedVal) return -{{{ cDefine('EWOULDBLOCK') }}};
 
@@ -800,7 +800,7 @@ var LibraryPThread = {
       PThread.setThreadStatusConditional(_pthread_self(), {{{ cDefine('EM_THREAD_STATUS_RUNNING') }}}, {{{ cDefine('EM_THREAD_STATUS_WAITFUTEX') }}});
 #endif
 
-      // Register globally which address the main thread is simulating to be futexWaiting on. When zero, main thread is not waiting on anything,
+      // Register globally which address the main thread is simulating to be waiting on. When zero, main thread is not waiting on anything,
       // and on nonzero, the contents of address pointed by __main_thread_futex_wait_address tell which address the main thread is simulating its wait on.
       Atomics.store(HEAP32, __main_thread_futex_wait_address >> 2, addr);
       while (addr) {
@@ -843,9 +843,9 @@ var LibraryPThread = {
     }
 
     // Wake any workers waiting on this address.
-    var ret = Atomics.futexWake(HEAP32, addr >> 2, count);
+    var ret = Atomics.wake(HEAP32, addr >> 2, count);
     if (ret >= 0) return ret + mainThreadWoken;
-    throw 'Atomics.futexWake returned an unexpected value ' + ret;
+    throw 'Atomics.wake returned an unexpected value ' + ret;
   },
 
   // Returns the number of threads (>= 0) woken up, or one of the values -EINVAL or -EAGAIN on error.
@@ -876,10 +876,10 @@ var LibraryPThread = {
     }
 
     // Wake any workers waiting on this address.
-    var ret = Atomics.futexWakeOrRequeue(HEAP32, addr >> 2, count, addr2 >> 2, cmpValue);
+    var ret = Atomics.wakeOrRequeue(HEAP32, addr >> 2, count, addr2 >> 2, cmpValue);
     if (ret == Atomics.NOTEQUAL) return -{{{ cDefine('EAGAIN') }}};
     if (ret >= 0) return ret + mainThreadWoken;
-    throw 'Atomics.futexWakeOrRequeue returned an unexpected value ' + ret;
+    throw 'Atomics.wakeOrRequeue returned an unexpected value ' + ret;
   },
 
   __atomic_is_lock_free: function(size, ptr) {
